@@ -22,6 +22,7 @@
 #include <QGraphicsScene>
 #include <QScopedPointer>
 #include <QHash>
+#include <QTouchEvent>
 #include <drumstick/pianokeybd.h>
 #include <drumstick/pianopalette.h>
 #include "pianokey.h"
@@ -133,6 +134,14 @@ namespace drumstick { namespace widgets {
         void saveData(QByteArray& ba);
         void loadData(QByteArray& ba);
 
+        bool touchScreenEvent(QTouchEvent *touchEvent);
+
+        void setUsingNativeFilter(const bool newState);
+        bool isUsingNativeFilter() const;
+
+        void setOctaveSubscript(const bool enable);
+        bool octaveSubscript() const;
+
     signals:
         /**
          * This signal is emitted for each Note On MIDI event created using
